<?php

namespace Drupal\cache_review;

use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Class for custom lazy builder service.
 */
class LazyBuilderDemo implements TrustedCallbackInterface {

  /**
   * Custom lazy builder callback.
   *
   * @param int $uid
   *   Current user id.
   * @param array $context_option
   *   Cache options.
   *
   * @return array
   *   Render array for lazy built item.
   */
  public function lazyBuilderCustom($uid, $context_option) {
    $time = "<span class='date'>" . date('H:i:s') . ' </span>';
    $text = sprintf('%s User id= %s. The lazy built item using service. Try to change $context_option to "user" and make this item uncachable. See cache_review\Controller\CacheReviewController::cachedLazy', $time, $uid);
    return [
      '#markup' => sprintf('(04) %s<br><strong><i>Cache options inside lazy placeholder: %s</i></strong>', $text, json_encode(['contexts' => [$context_option]])),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return [
      'lazyBuilderCustom',
    ];
  }

}
